@@ -7,7 +7,7 @@ from collections import defaultdict
 from dataclasses import dataclass, field
 from io import IOBase
 from typing import Union, List, Optional, Dict, DefaultDict, Tuple, BinaryIO, Any
-from urllib.parse import urlencode, urljoin
+from urllib.parse import urlencode, urljoin, uses_relative, uses_netloc, uses_params, uses_query, uses_fragment
 
 from requests import PreparedRequest
 from requests.auth import HTTPBasicAuth, HTTPDigestAuth, AuthBase
@@ -15,8 +15,6 @@ from requests.structures import CaseInsensitiveDict
 
 from .utils import get_real_file_path, triple_or_double_tostring, APPLICATION_JSON, json_to_urlencoded_array
 
-BASEIC_AUTHORIZATION_HEADER = "Authorization"
-
 try:
     import jstyleson as json
     from jsonschema import validate
@@ -48,6 +46,21 @@ MULTIPART_FORM_INPUT = "multipart/form-data"
 
 CONTENT_TYPE = 'content-type'
 
+UNIX_SOCKET_SCHEME = "http+unix"
+
+BASEIC_AUTHORIZATION_HEADER = "Authorization"
+
+
+def install_unix_socket_scheme():
+    uses_relative.append(UNIX_SOCKET_SCHEME)
+    uses_netloc.append(UNIX_SOCKET_SCHEME)
+    uses_params.append(UNIX_SOCKET_SCHEME)
+    uses_query.append(UNIX_SOCKET_SCHEME)
+    uses_fragment.append(UNIX_SOCKET_SCHEME)
+
+
+install_unix_socket_scheme()
+
 dothttp_model = metamodel_from_file(get_real_file_path(path="http.tx", current_file=__file__))
 
 
@@ -523,11 +536,33 @@ class HttpDefBase(BaseModelProcessor):
     def load_url(self):
         request_logger.debug(
             f'url is {self.http.urlwrap.url}')
+        url_path = self.get_updated_content(self.http.urlwrap.url)
         if base_http := self.base_http:
-            self.httpdef.url = urljoin(self.get_updated_content(base_http.urlwrap.url),
-                                       self.get_updated_content(self.http.urlwrap.url))
+            base_url = self.get_updated_content(base_http.urlwrap.url)
+            if not url_path:
+                self.httpdef.url = base_url
+            elif url_path.startswith("http://") or url_path.startswith("https://") or url_path.startswith(
+                    "http+unix://"):
+                self.httpdef.url = url_path
+            elif base_url.endswith("/") and url_path.startswith("/"):
+                self.httpdef.url = urljoin(base_url, url_path[1:])
+            elif url_path.startswith("/"):
+                self.httpdef.url = urljoin(base_url + "/", url_path[1:])
+            elif not base_url.endswith("/") and not url_path.startswith("/"):
+                self.httpdef.url = urljoin(base_url + "/", url_path)
+            else:
+                self.httpdef.url = urljoin(base_url, url_path)
         else:
-            self.httpdef.url = self.get_updated_content(self.http.urlwrap.url)
+            self.httpdef.url = url_path
+        if self.httpdef.url and not (
+                self.httpdef.url.startswith("https://")
+                or
+                self.httpdef.url.startswith("http://")
+                or
+                self.httpdef.url.startswith("http+unix://")
+
+        ):
+            self.httpdef.url = "http://" + self.httpdef.url
 
     def load_method(self):
         if method := self.http.urlwrap.method:
